@@ -6,4 +6,7 @@ def hi():
     return "hi"
 
 def t1():
-    print(np.ones((3,2)))
\ No newline at end of file
+    print(np.ones((3,2)))
+
+def t2():
+    print(np.__version__)
\ No newline at end of file
